@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,9 +21,21 @@
 #include <qtest.h>
 #include "pimcommon_debug.h"
 #include <QTextDocument>
+#include <QStandardPaths>
+#include <QProcess>
+
+#ifndef Q_OS_WIN
+void initLocale()
+{
+    setenv("LC_ALL", "en_US.utf-8", 1);
+}
+
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+#endif
 
 AutoCorrectionTest::AutoCorrectionTest()
 {
+    QStandardPaths::setTestModeEnabled(true);
     mConfig = KSharedConfig::openConfig(QStringLiteral("autocorrectiontestrc"));
     PimCommon::PimCommonSettings::self()->setSharedConfig(mConfig);
     PimCommon::PimCommonSettings::self()->load();
@@ -92,7 +104,6 @@ void AutoCorrectionTest::shouldUpperCaseFirstCharOfSentence()
     autocorrection.autocorrect(false, doc, position);
     QCOMPARE(doc.toPlainText(), QStringLiteral("Foo. Foo"));
     QCOMPARE(position, text.length());
-
 }
 
 void AutoCorrectionTest::shouldFixTwoUpperCaseChars()
@@ -175,7 +186,6 @@ void AutoCorrectionTest::shouldReplaceSingleQuote()
     position = text.length();
     autocorrection.autocorrect(false, doc, position);
     QCOMPARE(doc.toPlainText(), QString(simpleQuote.begin + text + simpleQuote.end));
-
 }
 
 void AutoCorrectionTest::shouldReplaceDoubleQuote()
@@ -299,7 +309,6 @@ void AutoCorrectionTest::shouldReplaceToTextFormat()
     QCOMPARE(position, 3);
 
     //TODO QCOMPARE(doc.toHtml(), text);
-
 }
 
 void AutoCorrectionTest::shouldReplaceAutoFraction()
@@ -324,7 +333,6 @@ void AutoCorrectionTest::shouldReplaceAutoFraction()
     autocorrection.autocorrect(false, doc, position);
     QCOMPARE(doc.toPlainText(), QString(QStringLiteral("½") + suffix));
     QCOMPARE(position, 1);
-
 }
 
 void AutoCorrectionTest::shouldNotAddSpaceWhenWeAlreadyHaveASpace()
@@ -392,7 +400,6 @@ void AutoCorrectionTest::shouldAutocorrectWord()
     autocorrection.autocorrect(false, doc, position);
     QCOMPARE(doc.toPlainText(), QString(convertWord + suffix));
     //FIXME ? QCOMPARE(position, convertWord.length());
-
 }
 
 void AutoCorrectionTest::shouldNotUpperCaseFirstCharOfSentence()
@@ -418,7 +425,6 @@ void AutoCorrectionTest::shouldNotUpperCaseFirstCharOfSentence()
     autocorrection.autocorrect(false, doc, position);
     QString result = QStringLiteral("foo. blabla Foo. Tt");
     QCOMPARE(doc.toPlainText(), result);
-
 }
 
 typedef QHash<QString, QString> mapAutoCorrect;
@@ -612,7 +618,7 @@ void AutoCorrectionTest::shouldAddNonBreakingSpaceBeforeAfterQuote()
     autocorrection.setLanguage(QStringLiteral("fr"));
     autocorrection.setAddNonBreakingSpace(true);
     //TODO fix me verify why it doesn't use no breaking space
-    const QChar nbsp = QChar(/*QChar::Nbsp*/QLatin1Char('b'));
+    const QChar nbsp = QChar(/*QChar::Nbsp*/ QLatin1Char('b'));
     autocorrection.setNonBreakingSpace(nbsp);
 
     PimCommon::AutoCorrection::TypographicQuotes doubleQuote;
@@ -668,4 +674,38 @@ void AutoCorrectionTest::shouldAddNonBreakingSpaceBeforeAfterQuote()
     QCOMPARE(doc.toPlainText(), QString(doubleQuote.begin + nbsp + text + nbsp + doubleQuote.end));
 }
 
+void AutoCorrectionTest::shouldLoadSaveAutocorrection_data()
+{
+    QTest::addColumn<QString>("filename");
+    QTest::newRow("empty") << QStringLiteral("empty");
+    QTest::newRow("custom-fr") << QStringLiteral("custom-fr");
+}
+
+void AutoCorrectionTest::shouldLoadSaveAutocorrection()
+{
+    QFETCH(QString, filename);
+    PimCommon::AutoCorrection autocorrection;
+    const QString originalFile = QLatin1String(AUTOCORRECTION_DATA_DIR) + QLatin1Char('/') + filename + QStringLiteral(".xml");
+    const QString refFile = QLatin1String(AUTOCORRECTION_DATA_DIR) + QLatin1Char('/') + filename + QStringLiteral("-ref.xml");
+    const QString generatedFile = QLatin1String(AUTOCORRECTION_DATA_DIR) + QLatin1Char('/') + filename + QStringLiteral("-generated.xml");
+
+    //First
+    autocorrection.loadGlobalFileName(originalFile, true);
+    autocorrection.writeAutoCorrectionXmlFile(generatedFile);
+
+    //Second
+    autocorrection.loadGlobalFileName(generatedFile, true);
+    autocorrection.writeAutoCorrectionXmlFile(generatedFile);
+
+    QStringList args = QStringList()
+                       << QStringLiteral("-u")
+                       << refFile
+                       << generatedFile;
+    QProcess proc;
+    proc.setProcessChannelMode(QProcess::ForwardedChannels);
+    proc.start(QStringLiteral("diff"), args);
+    QVERIFY(proc.waitForFinished());
+    QCOMPARE(proc.exitCode(), 0);
+}
+
 QTEST_MAIN(AutoCorrectionTest)
