@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,8 +20,7 @@
 
 #include "importabstractautocorrection.h"
 
-namespace PimCommon
-{
+namespace PimCommon {
 class ImportKMailAutocorrection : public ImportAbstractAutocorrection
 {
 public:
