@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,6 @@
 
 #include "configureplugindialog.h"
 #include <QVBoxLayout>
-#include <KLocalizedString>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <KConfigGroup>
@@ -27,8 +26,7 @@
 using namespace PimCommon;
 
 ConfigurePluginDialog::ConfigurePluginDialog(QWidget *parent)
-    : QDialog(parent),
-      mButtonBox(nullptr)
+    : QDialog(parent)
 {
 }
 
