@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,8 +21,7 @@
 #include "pimcommon_export.h"
 class QAction;
 class KActionCollection;
-namespace PimCommon
-{
+namespace PimCommon {
 class AbstractGenericPlugin;
 class GenericPlugin;
 class PIMCOMMON_EXPORT ActionType
@@ -34,13 +33,12 @@ public:
         File = 2,
         Action = 3,
         PopupMenu = 4,
-        ToolBar = 5
+        ToolBar = 5,
+        Message = 6,
+        Folder = 7
     };
     ActionType()
-        : mAction(nullptr),
-          mType(Tools)
     {
-
     }
 
     ActionType(QAction *action, Type type);
@@ -48,8 +46,8 @@ public:
     Type type() const;
 
 private:
-    QAction *mAction;
-    Type mType;
+    QAction *mAction = nullptr;
+    Type mType = Tools;
 };
 
 class AbstractGenericPluginInterfacePrivate;
@@ -73,6 +71,7 @@ public:
 
 Q_SIGNALS:
     void emitPluginActivated(PimCommon::AbstractGenericPluginInterface *interface);
+    void message(const QString &str);
 
 private:
     AbstractGenericPluginInterfacePrivate *const d;
