@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,13 +20,10 @@
 
 #include <QWidget>
 #include "pimcommon_private_export.h"
-class QPlainTextEdit;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
-namespace PimCommon
-{
+namespace PimCommon {
 class PIMCOMMON_TESTS_EXPORT LogActivitiesWidget : public QWidget
 {
     Q_OBJECT
@@ -42,7 +39,7 @@ Q_SIGNALS:
 
 private:
     void slotTextChanged();
-    KPIMTextEdit::PlainTextEditorWidget *mLog;
+    KPIMTextEdit::PlainTextEditorWidget *mLog = nullptr;
 };
 }
 
