@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,8 +21,7 @@
 #include <QObject>
 #include "pimcommon_export.h"
 class QNetworkConfigurationManager;
-namespace PimCommon
-{
+namespace PimCommon {
 class PIMCOMMON_EXPORT NetworkManager : public QObject
 {
     Q_OBJECT
@@ -34,7 +33,7 @@ public:
     QNetworkConfigurationManager *networkConfigureManager() const;
 
 private:
-    QNetworkConfigurationManager *mNetworkConfigureManager;
+    QNetworkConfigurationManager *mNetworkConfigureManager = nullptr;
 };
 }
 
