@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -37,6 +37,7 @@
 #include <kiconloader.h>
 #include <QIcon>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include "pimcommon_debug.h"
 #include <QPushButton>
 #include <QMenu>
@@ -53,35 +54,22 @@ class PimCommon::SimpleStringListEditorPrivate
 {
 public:
     SimpleStringListEditorPrivate()
-        : mListBox(nullptr),
-          mAddButton(nullptr),
-          mRemoveButton(nullptr),
-          mModifyButton(nullptr),
-          mUpButton(nullptr),
-          mDownButton(nullptr),
-          mButtonLayout(nullptr)
     {
-
     }
 
-    QListWidget   *mListBox;
-    QPushButton   *mAddButton;
-    QPushButton   *mRemoveButton;
-    QPushButton   *mModifyButton;
-    QPushButton   *mUpButton;
-    QPushButton   *mDownButton;
-    QVBoxLayout   *mButtonLayout;
+    QListWidget *mListBox = nullptr;
+    QPushButton *mAddButton = nullptr;
+    QPushButton *mRemoveButton = nullptr;
+    QPushButton *mModifyButton = nullptr;
+    QPushButton *mUpButton = nullptr;
+    QPushButton *mDownButton = nullptr;
+    QVBoxLayout *mButtonLayout = nullptr;
     QString mAddDialogLabel;
 };
 
-SimpleStringListEditor::SimpleStringListEditor(QWidget *parent,
-        ButtonCode buttons,
-        const QString &addLabel,
-        const QString &removeLabel,
-        const QString &modifyLabel,
-        const QString &addDialogLabel)
-    : QWidget(parent),
-      d(new SimpleStringListEditorPrivate)
+SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode buttons, const QString &addLabel, const QString &removeLabel, const QString &modifyLabel, const QString &addDialogLabel)
+    : QWidget(parent)
+    , d(new SimpleStringListEditorPrivate)
 {
     setAddDialogLabel(addDialogLabel);
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
@@ -98,7 +86,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent,
 
     if (buttons == None) {
         qCDebug(PIMCOMMON_LOG) << "SimpleStringListBox called with no buttons."
-                               "Consider using a plain QListBox instead!";
+                                  "Consider using a plain QListBox instead!";
     }
 
     d->mButtonLayout = new QVBoxLayout(); // inherits spacing
@@ -143,7 +131,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent,
     if (buttons & Up) {
         if (!(buttons & Down)) {
             qCDebug(PIMCOMMON_LOG) << "Are you sure you want to use an Up button"
-                                   "without a Down button??";
+                                      "without a Down button??";
         }
         d->mUpButton = new QPushButton(QString(), this);
         d->mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
@@ -157,7 +145,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent,
     if (buttons & Down) {
         if (!(buttons & Up)) {
             qCDebug(PIMCOMMON_LOG) << "Are you sure you want to use a Down button"
-                                   "without an Up button??";
+                                      "without an Up button??";
         }
         d->mDownButton = new QPushButton(QString(), this);
         d->mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
@@ -246,7 +234,7 @@ void SimpleStringListEditor::setButtonText(ButtonCode button, const QString &tex
     case Up:
     case Down:
         qCDebug(PIMCOMMON_LOG) << "SimpleStringListEditor: Cannot change text of"
-                               "Up and Down buttons: they don't contains text!";
+                                  "Up and Down buttons: they don't contains text!";
         return;
     default:
         if (button & All) {
@@ -264,8 +252,8 @@ void SimpleStringListEditor::addNewEntry()
 {
     bool ok = false;
     const QString newEntry = QInputDialog::getText(this, i18n("New Value"),
-                             d->mAddDialogLabel, QLineEdit::Normal, QString(),
-                             &ok);
+                                                   d->mAddDialogLabel, QLineEdit::Normal, QString(),
+                                                   &ok);
     if (ok && !newEntry.trimmed().isEmpty()) {
         insertNewEntry(newEntry);
     }
@@ -294,11 +282,13 @@ void SimpleStringListEditor::slotRemove()
     if (selectedItems.isEmpty()) {
         return;
     }
-    for (QListWidgetItem *item : selectedItems) {
-        delete d->mListBox->takeItem(d->mListBox->row(item));
+    if (KMessageBox::Yes == KMessageBox::warningYesNo(this, i18n("Do you want to remove selected text?"), i18n("Remove"))) {
+        for (QListWidgetItem *item : selectedItems) {
+            delete d->mListBox->takeItem(d->mListBox->row(item));
+        }
+        slotSelectionChanged();
+        Q_EMIT changed();
     }
-    slotSelectionChanged();
-    Q_EMIT changed();
 }
 
 QString SimpleStringListEditor::modifyEntry(const QString &text)
@@ -411,7 +401,6 @@ void SimpleStringListEditor::slotDown()
 
 void SimpleStringListEditor::slotSelectionChanged()
 {
-
     QList<QListWidgetItem *> lstSelectedItems = d->mListBox->selectedItems();
     const int numberOfItemSelected(lstSelectedItems.count());
     const bool uniqItemSelected = (numberOfItemSelected == 1);
@@ -433,13 +422,13 @@ void SimpleStringListEditor::slotSelectionChanged()
     const bool theFirst = (currentIndex == 0);
 
     if (d->mUpButton) {
-        d->mUpButton->setEnabled(aItemIsSelected && ((uniqItemSelected && !theFirst) ||
-                                 (!uniqItemSelected)) && !allItemSelected);
+        d->mUpButton->setEnabled(aItemIsSelected && ((uniqItemSelected && !theFirst)
+                                                     || (!uniqItemSelected)) && !allItemSelected);
     }
     if (d->mDownButton) {
-        d->mDownButton->setEnabled(aItemIsSelected &&
-                                   ((uniqItemSelected && !theLast) ||
-                                    (!uniqItemSelected)) && !allItemSelected);
+        d->mDownButton->setEnabled(aItemIsSelected
+                                   && ((uniqItemSelected && !theLast)
+                                       || (!uniqItemSelected)) && !allItemSelected);
     }
 }
 
@@ -447,19 +436,23 @@ void SimpleStringListEditor::slotContextMenu(const QPoint &pos)
 {
     QList<QListWidgetItem *> lstSelectedItems = d->mListBox->selectedItems();
     const bool hasItemsSelected = !lstSelectedItems.isEmpty();
-    QMenu *menu = new QMenu(this);
+    QMenu menu(this);
     if (d->mAddButton) {
-        menu->addAction(d->mAddButton->text(), this, &SimpleStringListEditor::slotAdd);
+        QAction *act = menu.addAction(d->mAddButton->text(), this, &SimpleStringListEditor::slotAdd);
+        act->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     }
     if (d->mModifyButton && (lstSelectedItems.count() == 1)) {
-        menu->addAction(d->mModifyButton->text(), this, &SimpleStringListEditor::slotModify);
+        QAction *act = menu.addAction(d->mModifyButton->text(), this, &SimpleStringListEditor::slotModify);
+        act->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
     }
     if (d->mRemoveButton && hasItemsSelected) {
-        menu->addSeparator();
-        menu->addAction(d->mRemoveButton->text(), this, &SimpleStringListEditor::slotRemove);
+        menu.addSeparator();
+        QAction *act = menu.addAction(d->mRemoveButton->text(), this, &SimpleStringListEditor::slotRemove);
+        act->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
+    }
+    if (!menu.isEmpty()) {
+        menu.exec(d->mListBox->mapToGlobal(pos));
     }
-    menu->exec(d->mListBox->mapToGlobal(pos));
-    delete menu;
 }
 
 QSize SimpleStringListEditor::sizeHint() const
@@ -471,4 +464,3 @@ QSize SimpleStringListEditor::sizeHint() const
     sh.setHeight(d->mButtonLayout->minimumSize().height());
     return sh;
 }
-
